#######################RECOMMENT STILL#########################################
canonical <- function( trueModel ) {
  #Function for turning a standard model structure into a canonical one.
  #Canonical here means that the model is represented by only direct effects
  #matrix B and covariance matrix of the disturbances

  #INPUT:
  # list with (model includes the confounding effects as hidden variables).
  # $B        - The direct effects matrix of the model 
  # $estd     - Standard deviations for each variable.
  # $const    - Constant terms.
  # $hidden   - A logical vector of which variables are hidden.

  #OUTPUT:
  # list with
  #  $B    - The B matrix of the model.
  #  $Ce   - The covariance matrix of the distubances.

  # Observed and hidden variables 
  nObs <- sum(trueModel$hidden==FALSE)
  nHidden <- sum(trueModel$hidden==TRUE)

  hiddenVar <- trueModel$hidden
  obsVar <- !hiddenVar

  # Total number of variables
  n <- length(trueModel$const)

  # Start by taking out (and accounting for) all self-loops
  B <- trueModel$B
  T <- mpinv(diag(n)-B)
  W <- mpinv(T)

  estd <- trueModel$estd
  for (i in 1:n) {
    estd[i] <- estd[i]/W[i,i]
    W[i,] <- W[i,]/W[i,i]
  }
  B <- diag(n)-W

  # Compute the new total effects among all variables
  T <- mpinv(diag(n)-B)

  # Compute direct effects among observed variables
  cT <- T[obsVar,obsVar]
  cW <- mpinv(cT)
  for (i in 1:nObs) {
    cW[i,] <- cW[i,]/cW[i,i]
  }
  cB <- diag(nObs)-cW

  # Compute the covariance matrix among all the observed variables
  B <- trueModel$B
  T <- mpinv(diag(n)-B) #Total effects

  Cobs <- T %*% diag(trueModel$estd^2) %*% t(T) # this is the covariance matrix of the data
  Cobs <- Cobs[obsVar,obsVar] #marginalizing to observed variables

  # Compute the covariance among the residuals in the canonical model
  # Covariance of the disturbances can be computer like this...

  #  cT <- mpinv(diag(nObs)-cB) #total effects of just the observed
  #  Ce <- mpinv(cT) %*% Cobs %*% mpinv(t(cT))
  Ce <- (diag(nObs)-cB)%*%Cobs%*%t(diag(nObs)-cB)

  # Return the canonical model
  canonicalModel <- list()
  canonicalModel$B <- cB
  canonicalModel$Ce <- Ce
  canonicalModel
}