chooseExperiment<-function(eqs, experiments) {
  #Chooses the best possible experiment to do next, based on new pair conditions
  # satisfied. For equally good experiment the one that comes first is chosen.
  #INPUT:
  # eqs         - Equations structure gotten from prev. experiments, see addEquations.
  # experiments - Array of experiments created by design Experiments.
  #OUTPUT:
  # index of the next experiment i.e. the column of experiment


  pcs<-rep(NA,ncol(experiments))
  besti<-NA
  n<-nrow(experiments)

  for ( i in 1:ncol(experiments) ) {
    if ( any( is.na( experiments[,i] ) ) ) {
      next; #an experiment that has already been done is marked with NA
    } 

    #here adding just mock equations to determine the new pairs satisfied
    Cmut <- array( 1, c(n,n) )
    eqsi <- addEquations( experiments[,i], Cmut, eqs )

    #Which pairs have the pair condition satisfied?
    pcs[i]<-sum(eqsi$sat)


    #better here to find maximum, to make sure things are deterministic
    if ( is.na(besti) || pcs[i] > pcs[besti] ) {
      besti<-i
    }
  }

  #returning the index of the next experiment
  besti
}

