enforce.sachs2<-function( Tvec, intervened, observed, tind, tdep ) {
  # Enforces rule 2, aka P-rule for Sachs sata.
  #INPUT:
  # Tvec           - Vector of experimental effects.
  # intervened     - Vector of variable indexes where intervened.
  # observed       - Vector of variable indexes where not intervened but observed.
  # tind           - If the abs. experimental effect is below this, variables are independent.
  # tdep           - If the abs. experimental effect is above this, variables are dependent.
  #OUTPUT:
  # An list with
  # Z - Which elements of B should be zero, integer matrix.
  # E - Which elements of Ce should be zero (Non are marked in this function.)

  Z<-array(0,c(length(Tvec),length(Tvec)) )
  for ( i in intervened ) {
    for ( o1 in observed ) {
      for ( o2 in observed ) {
        if ( o1 != o2 && abs(Tvec[o1]) < tind  &&  abs(Tvec[o2]) > tdep  ) {
         #   cat('<--------USED!!!!')
            #then there is no arc from o2 to o1
          Z[o1,o2]<-Z[o1,o2]+1
        }
      }
    }
  }
  list(Z=Z,E=array(0,dim(Z)))
}