experiment<-function(trueModel, newexp=NULL) {
  # Calculates the 'accurate' covariance matrix for the mutilated model.
  #INPUT:
  # trueModel - Model from randomModel().
  # newexp    - Vector where 1:s if intervened. If not given a random experiment
  #             is performed
  #OUTPUT:
  # An list with
  # $e - Vector where 1:s if intervened
  # $Cx - Covariance matrix of the data.

  Amut<-NA
  nObs<-sum(!trueModel$hidden)

  if ( is.null(newexp) ) { #If the new experiment is not given, draw one
     newexp <- 1*(runif(nObs)>0.5)
  }

  obsVar <- !trueModel$hidden #observed variables
  evec <- (newexp > 0) #intervened on variables

  #Finding the mutilated/manipulated B
  Bmut <- trueModel$B
  Bmut[which(evec),] <- 0


  Amut <- mpinv(diag(nrow(Bmut)) - Bmut)

  E<-list()
  E$e<-newexp

  estd <- trueModel$estd
  estd[which(evec)] <- 1

  E$Cx <- (Amut %*% diag(estd^2) %*% t(Amut))[obsVar,obsVar]

  E
}