graph2dot <- function( adj, C, filename, nodeshapevec, usearclabels, usenodelabels ) {
  # Produces a dot file from adjacency matrix and C matrix. See plotgraph.

  # number of nodes in graph
  nnodes <- dim(adj)[1]

  # node names currently just 1:nnodes
  nodelabels <- list()
  if ( usenodelabels ) {
    for (i in 1:nnodes) {
      nodelabels[[i]] <- colnames(adj)[i]
    }
  } else {
    for (i in 1:nnodes) {
      nodelabels[[i]] <- sprintf("%d",i)
    }
  }
    
  # node shapes: boolean vector indicating FALSE=round or TRUE=square 
  nodeshapes <- list()
  for (i in 1:nnodes) {
    if (nodeshapevec[i]) {
      nodeshapes[[i]] <- 'box'
    }
    else {
      nodeshapes[[i]] <- 'ellipse'
    }
  }
  
  # usearclabels is boolean, if TRUE we put numerical values on arcs
  if (usearclabels) {
    arclabels <- list()
    for (i in 1:(nnodes*nnodes)) {
      if ( is.na(adj[i]) ) {
        arclabels[[i]] <- 'NA'
      } else {
        if ( is.null(attr(adj,'sd')) ) {
          arclabels[[i]] <- sprintf("%.2f",adj[i])
        } else {
          arclabels[[i]] <- sprintf("%.2f+-%.2f",adj[i],attr(adj,'sd')[i])
        }     
      }
    }
  }

  # construct a format string for nodes
  nodeformat <- '  %d [label = "%s", shape = %s, style = "%s"];'#'

  # construct a format string for edges
  if (usearclabels) {
    attributes <- 'style = %s, color = %s, label = "%s", dir = %s'#'
  }
  else {
    attributes <- 'style = %s, color = %s, dir = %s'
  }
  edgeformat = paste(sep='','  %d -> %d [', attributes, '];')
  edgeformat2 = paste(sep='','  %d -> %d [style = %s, color = %s, dir = %s];')


  # if filename is empty then write to a tempfile
  if (filename == "") {
    filename <- "tempfile.dot"
  }


  # write the beginning of the file
  write('digraph G {', file=filename, append=FALSE, sep="")
  write('  center = 1;', file=filename, append=TRUE, sep="")
  write('  size = \"10, 10\";', file=filename, append=TRUE, sep="") #

  # write the nodes
  for (node in 1:nnodes) {
    thisnode <- sprintf(nodeformat, node, nodelabels[[node]],
                        nodeshapes[[node]], 'solid')
    write(thisnode, file=filename, append=TRUE, sep="")
  }



  # write the directed edges between the nodes
  for (node1 in 1:nnodes) {
    arcs <- which(adj[node1,]!=0 | is.na(adj[node1,]))
    for (node2 in arcs) {
      style <- 'solid'
      color <- 'black'
      if ( is.na( adj[node1,node2] ) ) {
        color <- 'gray'
      }

      dowrite <- TRUE
      if (usearclabels) {
        thisarc <- sprintf(edgeformat, node2, node1, style, color,
                           arclabels[[(node2-1)*nnodes + node1]], 'forward')
      } else {
        if (adj[node2,node1]!=0) {
          if (node2<node1) {
            color <- 'red'
            thisarc <- sprintf(edgeformat, node2, node1, style, color, 'none' )
          } else {
            dowrite <- FALSE
          }
        } else {
          thisarc <- sprintf(edgeformat, node2, node1, style, color, 'forward')
        }
      }
      if (dowrite) {
        write(thisarc, file=filename, append=TRUE, sep="")
      }
    }
  }
  
  # write bidirected dashed edges between the nodes
  if (any(C!=0)) {
  for (node1 in 1:nnodes) {
    arcs <- which(C[node1,]!=0)
    for (node2 in arcs) {
      style <- 'dashed'  # 'dashed' or 'dotted'?
      color <- 'gray'
      dowrite <- TRUE
     	thisarc <- sprintf(edgeformat2, node2, node1, style, color, 'both')

      write(thisarc, file=filename, append=TRUE, sep="")
    }
  }
  }
  
  write('}', file=filename, append=TRUE, sep="")
}
