
# STARTING UP:
#
# > source('load.R')
# > loud()
# > main(1)

main <- function( task ) {

 #general tests to run

  #------------------------------------------------------------------------
  # Task 1: A run with accurate covariance matrices, All faithfulness rules.
  #------------------------------------------------------------------------

  if (task==1) {
    #creating the model
    M<-randomModel(10,10,10)
    C<-canonical(M) #find the true result
    R<-runinference.accurate(M, rules=c(1,2,3), verbose=1)

    cat('True direct effects model:\n');print(round(C$B,2))
    cat('Learned direct effects model:\n');print(round(R$B,2))

    plotgraph(R$B)

  } 

  #------------------------------------------------------------------------
  # Task 2: A run with sampled covariance matrices. All faithfulness rules.
  #------------------------------------------------------------------------

  if (task==2) {
    #creating the model
    M<-randomModel(10,10,10)
    C<-canonical(M) #find the true result
    R<-runinference.sampling(M, rules=c(1,2,3), verbose=1)

    cat('True direct effects model:\n');print(round(C$B,2))
    cat('Learned direct effects model:\n');print(round(R$B,2))

    R$B[abs(R$B)<0.05]<-0 #some pruning before plotting
    plotgraph(round(R$B,2))

  }
  #------------------------------------------------------------------------
  # Task 3: Accurate covariance matrices, no Faithfulness
  #------------------------------------------------------------------------

  if (task==3) {
    #creating the model
    M<-randomModel(10,10,10)
    C<-canonical(M) #find the true result
    R<-runinference.accurate(M, rules=c(), verbose=1)

    cat('True direct effects model:\n');print(round(C$B,2))
    cat('Learned direct effects model:\n');print(round(R$B,2))

    plotgraph(R$B)

  }

  #------------------------------------------------------------------------
  # Task 4: 
  #------------------------------------------------------------------------

  if (task==4) {
    #creating the model
    M<-randomModel(10,10,10)
    C<-canonical(M) #find the true result
    R<-runinference.sampling(M, rules=c(), verbose=1)

    cat('True direct effects model:\n');print(round(C$B,2))
    cat('Learned direct effects model:\n');print(round(R$B,2))

    R$B[abs(R$B)<0.05]<-0 #some pruning before plotting
    plotgraph(round(R$B,2))
 
  }



  #reproducing the results in the paper

  #------------------------------------------------------------------------
  # Task 101: Running accurate tests. Needed for figure 3.
  #------------------------------------------------------------------------

  if (task==101) {
    options(error=recover)
    test.accurate() #for faster try test.accurate(1:2)
    test.accurate.print()
  }


  #------------------------------------------------------------------------
  # Task 102: Reproducing the figure 3. Task 101 needs to be run first.
  #------------------------------------------------------------------------

  if (task==102) {
    plot2()
  }

  #------------------------------------------------------------------------
  # Task 201: Running sampling tests. Needed for figure 4.
  #------------------------------------------------------------------------

  if (task==201) {
    options(error=recover)
    test.sampling() #for faster try test.sampling(1:2)
    test.sampling.print()
  }


  #------------------------------------------------------------------------
  # Task 202: Reproducing the figure 4. Task 201 needs to be run first.
  #------------------------------------------------------------------------

  if (task==202) {
    plot1()
  }


  #------------------------------------------------------------------------
  # Task 301: Reproducing the figures for sachs data. After running the
  # graph corresponding figure 5 should be in skeleton05.pdf
  #------------------------------------------------------------------------

  if (task==301) {
    #first do 
    sachs.faithful.run()
    #then do the analysis and produce figures
    sachs()
  }

}
