plotgraph <- function( B, C=array(0,dim(B)), filename='tempfile' ) {
  # Plots as a graph directs effects and confounding covariances.
  #INPUT:
  # B - Model from randomModel().
  # C - Covarianve matrix of the erro terms.
  # filename - The name with which dot, ps and pdf files are created.
  #OUTPUT:
  # filename.dot
  # filename.ps
  # filename.pdf - This is shown by gv.

  if ( is.na(psviewer) ) {
    return(TRUE)
  }


  #some pruning if not done earlier
  B[abs(B) < 1e-5] <- 0
  C[abs(C) < 1e-5] <- 0

  # Names of the files
  dotfilename <- paste(sep='',filename,'.dot')
  psfilename <- paste(sep='',filename,'.ps')
  pdffilename <- paste(sep='',filename,'.pdf')


  # Hidden variables are squares, observed are circles
  ngvec <- rep(FALSE,nrow(B)) #all observed
  nodeshapevec <- ngvec


  # If B is binary, we do not plot labels.
  if (all((B==0) | (B==1))) {
    usearclabels <- FALSE
  } else {
    usearclabels <- TRUE
  }

  if ( is.null(colnames(B) ) ) {
    usenodelabels <- FALSE
  } else {
    usenodelabels <- TRUE
  }

  # Take out diagonal and upper triangular part of C, because
  # C is the covariance matrix of the errors; we do not care for the
  # diagonal which contains the individual variances, and it should
  # be symmetric so we only use the lower-triangular part of it.
  C <- C-diag(diag(C))
  C[upper.tri(C)] <- 0

  # Create the DOT file
  graph2dot( B, C, dotfilename, nodeshapevec, usearclabels, usenodelabels )

  useprog <- 'dot'
  progcall <- paste(sep='',useprog,' -Tps ',dotfilename,' -o ',psfilename)
  system(progcall)

  #epscall <- paste( 'epstopdf ',psfilename,sep='')
  #system(epscall,wait=TRUE)

  gvcall <- paste(sep='',psviewer,' ',psfilename)
  system(gvcall,wait=FALSE)

}

