
randomModel <- function( n, edges, confounders ) {
  #Function creating a random model.
  #INPUT:
  # n           - The number of nodes in the network. 
  # edges       - How many edges to put in?
  # confounders - How many pairs of visible variables should have nonzero 
  #               disturbance covariances.

  #OUTPUT:
  # list with (model includes the confounding effects as hidden variables).
  # $B        - The direct effects matrix of the model 
  # $estd     - Standard deviations for each variable.
  # $const    - Constant terms.
  # $hidden   - A logical vector of which variables are hidden.



  nObs <- n
  nHidden <- confounders

  n<- nObs + nHidden

  #all the pairs of the observed variables are here
  library(gtools)

  confoundedpairs<-combinations(nObs, 2)
  confoundedpairs<-confoundedpairs[sample(nrow(confoundedpairs),confounders),,drop=FALSE]

  edgedpairs<-permutations(nObs, 2)
  edgedpairs<-edgedpairs[sample(nrow(edgedpairs),edges),,drop=FALSE]

  bB<-array(0,c(n,n))
  for ( i in 1:nrow(edgedpairs) ) {
    bB[edgedpairs[i,1],edgedpairs[i,2]]<-1
  }

  for ( i in 1:nrow(confoundedpairs) ) {
     bB[ confoundedpairs[i,1], i + nObs ] <- 1
     bB[ confoundedpairs[i,2], i + nObs ] <- 1
  }


  B <- 2
  maxabs <- 0.9

  #this is the stability test also in the old code
  while (max(abs(eigen(B)$values)) >= maxabs ) {
    B <- bB*matrix(runif(n*n,0.3,0.8),n,n)*matrix(sample(c(-1,1),n*n,replace=TRUE),n,n)
  }

  hidden <- c(rep(FALSE,nObs),rep(TRUE,nHidden))

  # Return the model
  model <- list()
  model$B <- B
  model$estd <- abs(rnorm(n)*0.5)+1
  model$const <- rnorm(n)
  model$hidden <- hidden
  model
}
