sachs.analysis<-function(S, experiments=3:6,
                         zero=array(0,c(11,11)),
                         add_noise=FALSE ) {

  # Runs analysis on Sachs data.
  #INPUT:
  # S           - Sachs data from sachsdata().
  # experiment  - Indexes of experiments to use?
  # zero        - A matrix where nonzero element means that that element of B
  #               is set to zero.
  # addnoise    - Whether to add noise from the nullspace.
  #OUTPUT:
  # Matrix of direct effects.

  n <- ncol(S$D[[1]])
  nexp <- length(experiments) 

  eqs<-NULL
  Clist<-list()
  Elist<-list()

  # Compute the total effects from each perturbed variable
  for (i in 1:nexp) {
    ei<-experiments[i]

    # Indices of experiment and variable, and whether excited or inhibited
    intervened <- which(S$Ei[,ei] == 1) 

    Cmut<-array(NA,c(n,n)) #saving the covariance matrix
    Cmut[,intervened]<-S$Tvec[[ei]]
    Cmut[intervened,]<-S$Tvec[[ei]]

    #add equations from this experiment
    eqs<-addEquations( S$Ei[,ei], Cmut, eqs );

  }

  for ( i in 1:nrow(zero) ) {
    for ( j in (1:ncol(zero))[-i] ) {
      if ( zero[i,j] > 0) {
        eqs<-addZeroEquation(eqs,i,j,w=zero[i,j])
      }
    }
  }

  b<-mpinv(eqs$K)%*%eqs$k

  if ( add_noise ) {
    N<-Null3( eqs$K, 0.1 )
    #cat('Null space dim:',ncol(N),'\n');
    noise<-sample( c(-1,1), ncol(N), replace=TRUE )*10
    b<-b+N%*%noise
  }

  B<-b.to.B(b, eqs$P, eqs$n )

  B
}