sachs.bootstrap<-function(zero=array(FALSE,c(4,4)), bootstraps=100) {
  # Runs analysis several times on Sachs data.
  #INPUT:

  # zero        - A matrix where nonzero element means that that element of B
  #               is set to zero.
  # bootstraps  - How many times to run the analysis.
  #OUTPUT:
  # Matrix of direct effects. attr(B,'sd') reports the stdev. of the parameters.

  set.seed(0)
  S <- sachsdata(resample=FALSE)

  n<-ncol(S$D[[1]])

  B<-array(NA,c(n,n,bootstraps) )

  #do first analysis with the actual data
  Sa<-sachs.analysis(S, zero=zero, add_noise=TRUE )
  B[,,1]<-Sa

  for ( b in 2:bootstraps) {
    Si <- sachsdata(resample=TRUE)
    Sa<-sachs.analysis(Si, zero=zero, add_noise=TRUE )
    B[,,b]<-Sa
  }

  mB<-array(NA,c(11,11) )
  sdB<-array(NA,c(11,11) )

  for ( i in 1:nrow(B) ) {
    for ( j in 1:ncol(B) ) {
      b<-B[i,j,]
      mB[i,j]<-mean(b)
      sdB[i,j]<-sd(b)
    }
  }

  colnames(mB)<-rownames(mB)<-colnames(sdB)<-rownames(sdB)<-c('Raf','Mek',
                'Plcg','PIP2','PIP3','Erk','Akt','PKA','PKC','P38','Jnk')

  attr(mB,'sd')<-sdB

  mB
}