sachs.faithful.run<-function() {
  #runs the faithfulness rules with various settings
  #for the sachs data and saves results to sachs.faithful.Rdata

  set.seed(0);Z1_05<-sachs.faithful( rules=c(1), significance=0.05 )
  set.seed(0);ZA_05<-sachs.faithful( rules=c(1,2,3), significance=0.05 )
  set.seed(0);Z1_10<-sachs.faithful( rules=c(1), significance=0.1 )
  set.seed(0);ZA_10<-sachs.faithful( rules=c(1,2,3), significance=0.1 )

  names<-c('Raf','Mek','Plcg','PIP2','PIP3','Erk','Akt','PKA','PKC','P38','Jnk')

  colnames(Z1_05)<-rownames(Z1_05)<-names
  colnames(ZA_05)<-rownames(ZA_05)<-names
  colnames(Z1_10)<-rownames(Z1_10)<-names
  colnames(ZA_10)<-rownames(ZA_10)<-names

  save(Z1_05,ZA_05,Z1_10,ZA_10,file='sachs.faithful.Rdata')
}


sachs.faithful<-function(fexperiments=c(1,3:6), rules=c(1,2,3), significance=0.05 ) {
  #Bootstraps the faithfulness inference for sachs data.
  # INPUT:
  # fexperiments - Which experiments to use for faithfulness.
  # rules        - Vector which of the faithfulness rules use.
  #                1 - The skeleton rules marginalized over intervened. (See below.)
  #                2 - The first orientation rule, here with thresolds rather than tests.
  #                3 - The additional rule, see enforce.sachs3.R
  #                (Standard rule 3 is not applicable since covariance matrix can
  #                 be calculated marginalized over intervened.
  # significance - Significance level used for PC search. Max set size is 2. 


  set.seed(0)
  n<-11

  mask <- array(TRUE,c(n,n))
  diag(mask) <- FALSE

  Z<-array( 0, c(n,n) )

  for ( b in 1:100 ) {
    #Reads the Sachs data and resamples it.
    S<-sachsdata(resample=TRUE)


    for ( ei in fexperiments ) {
      intervened <- which( S$Ei[,ei] == 1 )
      observed <- which( S$Ei[,ei] == 0 )

      Cmut<- cov( S$D[[ei]][,observed] ) #for pc only putting in the observed
      attr(Cmut,'N')<-nrow( S$D[[ei]] ) #this is marginalizing over the intervened
                                        #this needs to be done since in the data
                                        #the intervened variable data is not ok.

      pc_result <- pc_skeleton( Cmut, nrow( S$D[[ei]] ) , significance=significance, maxsetsize=2)
      G<-array(NA,c(n,n))
      G[observed,observed] <- pc_result$skel
      G[intervened,observed] <- 1  #arcs from intervened to observed and vice versa are put there not be set to zero
      G[observed,intervened] <- 1

      if ( any( rules == 1 ) ) {
        R1<-enforce.rule1( G=G, intervened=c() )
        Z<-Z+R1$Z
      }
      if ( any( rules == 2 ) & length(intervened) > 0 ) {
        R2<-enforce.sachs2( S$Tvec[[ei]],intervened,observed,tind=0.1,tdep=0.2 )
        Z<-Z+R2$Z
      }

      if ( any(rules==3 ) & length(intervened) > 0 ) {
        R2<-enforce.sachs3( S$Tvec[[ei]],intervened,observed,tind=0.1 )
        Z<-Z+R2$Z
      }

     }
   }

  Z
}
