
#input directory for the Sachs data...
#

sachsdata<-function( takelog=TRUE, resample=FALSE ) {
  # Reads in Sachs data from the files. (sachsdir defined in parameters)
  #INPUT:
  # takelog     - Whether to take logarithm of the data.
  # resample    - If true each data set is resampled for bootstrapping. 
  #OUTPUT:
  # A list with
  # $Ei           - Matrix, columns define which elements are intervened on in each
  #                 experiment.
  # $backgroud    - Index of background conditions.
  # $excite       - Whether the intervened variable was excited rather than suppressed.
  # $quantileused - Which quantile was used as the correct value of an int. variable?
  # $takelog      - Was logarithm taken.
  # $D[[i]]       - Data of the i:th experiment.
  # $Tvec[[i]]    - Experimental effects in i:th experiment.

  D<-list()

  #which variables was manipulated in which experiment 
  D$Ei<-array(0,c(11,14))

  D$Ei[ ,1]<-0 #passive data for background condition 1
  D$Ei[ ,2]<-0 #passive data for background condition 2
  D$Ei[7,3]<-1
  D$Ei[9,4]<-1
  D$Ei[4,5]<-1
  D$Ei[2,6]<-1
  D$Ei[7,7]<-1
  D$Ei[9,8]<-1
  D$Ei[8,9]<-1
  D$Ei[7,10]<-1
  D$Ei[9,11]<-1
  D$Ei[4,12]<-1
  D$Ei[2,13]<-1
  D$Ei[7,14]<-1

  #background conditions as integers
  D$background <- c(1,2,rep(1,5),3,4,rep(2,5))

  #in which experiments variables were exicited rather than inhibited
  D$excite <- rep(FALSE,14)
  D$excite[-c(3,4,5,6)] <- NA

  D$quantileused <- 0.001


  D$takelog <- takelog

  # Read in all 14 experiments, take logs if requested
  D$D <- list()
  D$Tvec <- list()
  i <- 1
  for (i in 1:14) {
    fname <- paste(sachs_dir,'experiment',i,'.csv',sep='') #directory corrected
    D$D[[i]] <- read.table(fname, header=TRUE, sep=',')
    colnames(D$D[[i]])<-c('Raf','Mek','Plcg','PIP2','PIP3','Erk','Akt','PKA','PKC','P38','Jnk')

    if (takelog) {
      D$D[[i]] <- log(D$D[[i]])
    }

    if ( resample ) {
      D$D[[i]] <- D$D[[i]][sample(nrow(D$D[[i]]),nrow(D$D[[i]]),replace=TRUE),]
    }


    if ( any ( i == c(3,4,5,6) ) ) {
      intervened<-which(D$Ei[,i] == 1 )
      X<-D$D[[i]]
      obsmean <- colMeans(D$D[[1]])
      exmean <- colMeans(X)

      # Replace the intervened-upon variable by its interventional value
      # here passive data used
      Xi <- D$D[[1]][,intervened]

      Xiset <- quantile(Xi,D$quantileused)
      exmean[intervened] <- Xiset
 
      # Compute the changes in means divided by changes in intervened var
      T<-(exmean-obsmean)/(Xiset-obsmean[intervened])

      T[intervened]<-NA 
      #cat('Experimental effects:\n')
      #print(T)

      D$Tvec[[i]]<-T
      attr(D$Tvec,'N')<-nrow(X)
    } else {
      D$Tvec[[i]]<-NA
    }
  }

  D
}











