undetermined<-function(eqs,ntol=1e-5,ztol=1e-5) {
  #Prints test results for the accurate covariance tests.
  #INPUT:
  # eqs           - Structures of the equations
  # ntol          - if sing. value < ntol then value is zero and vector is part
  #                 of the nullspace.
  # ztol          - If in a nullspace vector th element^2 > ztol then it is not determined.
  #OUTPUT:
  # A matrix of dimension of B where
  #  TRUE         - If a element of B is undetermined.
  #  FALSE        - If a elemnt is determined.


  N<-Null3(eqs$K,tol=ntol)
  uB<-sqrt( b.to.B( rowSums(N^2), eqs$P, eqs$n ) )

  uB > ztol
}

Null3<-function (M,tol=1e-5) {
  S <- eigen(t(M)%*%M)
  set<-which(abs(S$values) < tol)
  N <- S$vectors[, set, drop = FALSE]

# Possible printing...:
#    cat('Nullspace: zero tol=', tol,'\n');
#    cat('Dim:', dim(M) , '\n')
#    cat('QR rank:', qr(M)$rank, '\n' )
#    cat('Singular vals:', S$values, '\n' )
#    cat('N-dim:', dim(N), '\n' )

  N
}


